@@ -32,6 +32,7 @@ from typing import Callable
 import sys
 import os
 import re
+import ast
 import signal
 import argparse
 import locale
@@ -303,7 +304,9 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         self._skin_tone_popover: Optional[Gtk.Popover] = None
         self._skin_tone_selected_popover: Optional[Gtk.Popover] = None
 
-        self._main_container = Gtk.VBox()
+        self._main_container = Gtk.Box()
+        self._main_container.set_orientation(Gtk.Orientation.VERTICAL)
+        self._main_container.set_spacing(0)
         self.add(self._main_container) # pylint: disable=no-member
         self._header_bar = Gtk.HeaderBar()
         self._header_bar.set_hexpand(True)
@@ -315,23 +318,23 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         self._main_menu_popover = Gtk.Popover()
         self._main_menu_popover.set_relative_to(self._main_menu_button)
         self._main_menu_popover.set_position(Gtk.PositionType.BOTTOM)
-        self._main_menu_popover_vbox = Gtk.VBox()
+        self._main_menu_popover_vbox = Gtk.Box()
+        self._main_menu_popover_vbox.set_orientation(Gtk.Orientation.VERTICAL)
+        self._main_menu_popover_vbox.set_spacing(0)
         self._main_menu_clear_recently_used_button = Gtk.Button(
             label=_('Clear recently used'))
         self._main_menu_clear_recently_used_button.connect(
             'clicked', self.on_clear_recently_used_button_clicked)
-        self._main_menu_popover_vbox.pack_start(
-            self._main_menu_clear_recently_used_button, False, False, 0)
+        self._main_menu_popover_vbox.add(
+            self._main_menu_clear_recently_used_button)
         if not self._modal:
             self._main_menu_about_button = Gtk.Button(label=_('About'))
             self._main_menu_about_button.connect(
                 'clicked', self.on_about_button_clicked)
-            self._main_menu_popover_vbox.pack_start(
-                self._main_menu_about_button, False, False, 0)
+            self._main_menu_popover_vbox.add(self._main_menu_about_button)
         self._main_menu_quit_button = Gtk.Button(label=_('Quit'))
         self._main_menu_quit_button.connect('clicked', self.on_delete_event)
-        self._main_menu_popover_vbox.pack_start(
-            self._main_menu_quit_button, False, False, 0)
+        self._main_menu_popover_vbox.add(self._main_menu_quit_button)
         self._main_menu_popover.add(self._main_menu_popover_vbox)
         self._main_menu_button.connect(
             'clicked', self.on_main_menu_button_clicked)
@@ -410,7 +413,7 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
             'grab-focus', self.on_search_entry_grab_focus)
 
         self._browse_paned = Gtk.HPaned()
-        self._main_container.pack_start(self._browse_paned, True, True, 0)
+        self._main_container.add(self._browse_paned)
         self._browse_paned.set_wide_handle(True)
         self._browse_paned.set_hexpand(True)
         self._browse_paned.set_vexpand(True)
@@ -436,13 +439,18 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         self._long_press_gestures: List[
             Tuple[Any, Tuple[Any, Any, Any, Any]]] = []
 
-        self._left_pane = Gtk.VBox()
+        self._left_pane = Gtk.Box()
+        self._left_pane.set_orientation(Gtk.Orientation.VERTICAL)
+        self._left_pane.set_spacing(0)
         self._left_pane.set_homogeneous(False)
-        self._left_pane.pack_start(self._search_bar, False, False, 0)
-        self._left_pane.pack_start(self._browse_treeview_scroll, True, True, 0)
+        self._left_pane.add(self._search_bar)
+        self._left_pane.add(self._browse_treeview_scroll)
 
-        self._right_pane = Gtk.VBox()
-        self._right_pane.pack_start(self._flowbox_scroll, True, True, 0)
+        self._right_pane = Gtk.Box()
+        self._right_pane.set_orientation(Gtk.Orientation.VERTICAL)
+        self._right_pane.set_spacing(0)
+        self._right_pane.set_homogeneous(False)
+        self._right_pane.add(self._flowbox_scroll)
 
         self._browse_paned.pack1(
             self._left_pane, resize=True, shrink=True)
@@ -538,9 +546,9 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         if _ARGS.debug:
             LOGGER.debug(
                 'natural_width_search_entry = %s '
-                %natural_width_search_entry
-                + 'natural_width_search_bar = %s\n'
-                %natural_width_search_bar)
+                'natural_width_search_bar = %s\n',
+                natural_width_search_entry,
+                natural_width_search_bar)
         self._browse_paned.set_position(natural_width_search_bar)
 
         self._selection_clipboard = Gtk.Clipboard.get(
@@ -650,10 +658,10 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         '''
         descriptions = []
         descriptions.append(
-            ' '.join(['U+%X' %ord(character) for character in emoji]))
+            ' '.join([f'U+{ord(character):04X}' for character in emoji]))
         for language in itb_util.expand_languages(self._languages):
             names = self._emoji_matcher.names(emoji, language=language)
-            description = '<b>%s</b>' %language
+            description = f'<b>{language}</b>'
             description_empty = True
             if names:
                 description += '\n' + html.escape(', '.join(names))
@@ -680,12 +688,12 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
             fonts_description += '\n'
             code_points = ''
             for char in text:
-                code_points += ' U+%X' %ord(char)
+                code_points += f' U+{ord(char):04X}'
             fonts_description += (
-                '<span font="%s" fallback="%s" >'
-                %(self._font, str(self._fallback).lower())
+                f'<span font="{self._font}" '
+                f'fallback="{str(self._fallback).lower()}" >'
                 + text + '</span>'
-                + '<span fallback="true">%s</span>' % code_points)
+                + f'<span fallback="true">{code_points}</span>')
             fonts_description += ': ' + font_family
         descriptions.append(fonts_description)
         if self._emoji_matcher.unicode_version(emoji):
@@ -694,9 +702,9 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
                 + self._emoji_matcher.unicode_version(emoji))
         if _ARGS.debug:
             descriptions.append(
-                'emoji_order = %s' %self._emoji_matcher.emoji_order(emoji))
+                f'emoji_order = {self._emoji_matcher.emoji_order(emoji)}')
             descriptions.append(
-                'cldr_order = %s' %self._emoji_matcher.cldr_order(emoji))
+                f'cldr_order = {self._emoji_matcher.cldr_order(emoji)}')
             descriptions.append(
                 'Emoji properties from unicode.org:' + '\n'
                 + ', '.join(self._emoji_matcher.properties(emoji)))
@@ -803,15 +811,14 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
             gtk_label = Gtk.Label()
             # Make font for emoji large using pango markup
             text = (
-                '<span font="%s %s" fallback="%s">'
-                %(self._font, self._fontsize, str(self._fallback).lower())
+                f'<span font="{self._font} {self._fontsize}" '
+                f'fallback="{str(self._fallback).lower()}">'
                 + html.escape(emoji)
                 + '</span>')
             if itb_emoji.is_invisible(emoji):
                 text += (
-                    '<span fallback="false" font="%s">'
-                    %(self._fontsize / 2)
-                    + ' U+%X ' %ord(emoji)
+                    f'<span fallback="false" font="{self._fontsize / 2}">'
+                    f' U+{ord(emoji):04X} '
                     + self._emoji_matcher.name(emoji)
                     + '</span>')
             gtk_label.set_text(text)
@@ -884,11 +891,14 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
                 with open(self._options_file,
                           mode='r',
                           encoding='UTF-8') as options_file:
-                    options_dict = eval(options_file.read())
-            except (PermissionError, SyntaxError, IndentationError):
-                LOGGER.exception('Error when reading options')
-            except Exception as dummy_exception:
-                LOGGER.exception('Unknown error when reading options')
+                    options_dict = ast.literal_eval(options_file.read())
+            except (PermissionError, SyntaxError, IndentationError) as error:
+                LOGGER.exception('Error when reading options: %s: %s',
+                                 error.__class__.__name__, error)
+            except Exception as error:
+                LOGGER.exception(
+                    'Unexpected error when reading options: %s: %s',
+                    error.__class__.__name__, error)
             else: # no exception occured
                 if _ARGS.debug:
                     LOGGER.debug(
@@ -947,13 +957,15 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
                 with open(self._recently_used_emoji_file,
                           mode='r',
                           encoding='UTF-8') as recently_used_file:
-                    recently_used_emoji = eval(recently_used_file.read())
-            except (PermissionError, SyntaxError, IndentationError):
-                import traceback
-                traceback.print_exc()
-            except Exception as dummy_exception:
-                import traceback
-                traceback.print_exc()
+                    recently_used_emoji = ast.literal_eval(
+                        recently_used_file.read())
+            except (PermissionError, SyntaxError, IndentationError) as error:
+                LOGGER.exception('Error reading recently used emoji: %s: %s',
+                                 error.__class__.__name__, error)
+            except Exception as error:
+                LOGGER.exception(
+                    'Unexpected error reading recently used emoji: %s: %s',
+                    error.__class__.__name__, error)
             else: # no exception occured
                 if _ARGS.debug:
                     LOGGER.debug(
@@ -1084,7 +1096,8 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
                     + ', '.join(keywords))
                 break
 
-    def _print_profiling_information(self) -> None:
+    @staticmethod
+    def _print_profiling_information() -> None:
         '''
         Print some profiling information to the log.
         '''
@@ -1227,12 +1240,11 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
             label = Gtk.Label()
             # Make font for emoji large using pango markup
             label.set_text(
-                '<span font="%s %s" fallback="%s">'
-                %(self._font, self._fontsize, str(self._fallback).lower())
+                f'<span font="{self._font} {self._fontsize}" '
+                f'fallback="{str(self._fallback).lower()}">'
                 + html.escape(emoji)
                 + '</span>'
-                + '<span font="%s">'
-                %(self._fontsize / 2)
+                + f'<span font="{self._fontsize / 2}">'
                 + ' ' + html.escape(name)
                 + '</span>')
             label.set_use_markup(True)
@@ -1373,10 +1385,10 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
             return
         if _ARGS.debug:
             LOGGER.debug(
-                'on_label_selected(): model[iterator] = %s\n'
-                %model[iterator][:]
-                + 'self._currently_selected_label = %s\n'
-                %repr(self._currently_selected_label))
+                'model[iterator] = %s\n'
+                'self._currently_selected_label = %s\n',
+                model[iterator][:],
+                repr(self._currently_selected_label))
         self._search_bar.set_search_mode(False)
         self._browse_treeview.grab_focus()
         language = model[iterator][1]
@@ -1542,14 +1554,13 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
             if emoji:
                 emoji = self._variation_selector_normalize_for_font(emoji)
                 new_text = (
-                    '<span font="%s %s" fallback="%s">'
-                    %(self._font, self._fontsize, str(self._fallback).lower())
+                    f'<span font="{self._font} {self._fontsize}" '
+                    f'fallback="{str(self._fallback).lower()}">'
                     + html.escape(emoji)
                     + '</span>')
                 if name:
                     new_text += (
-                        '<span fallback="true" font="%s">'
-                        %(self._fontsize / 2)
+                        f'<span fallback="true" font="{self._fontsize / 2}">'
                         + html.escape(name)
                         + '</span>')
                 label.set_text(new_text)
@@ -1626,16 +1637,16 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
             # in a search results flowbox and we do *not* want
             # to replace the emoji.
             new_text = (
-                '<span font="%s %s" fallback="%s">'
-                %(self._font, self._fontsize, str(self._fallback).lower())
+                f'<span font="{self._font} {self._fontsize}" '
+                f'fallback="{str(self._fallback).lower()}">'
                 + html.escape(emoji)
                 + '</span>')
             label.set_text(new_text)
             label.set_use_markup(True)
         GLib.timeout_add(500, self._skin_tone_selected_popover_popdown)
 
+    @staticmethod
     def on_flowbox_event_box_long_press_begin(
-            self,
             gesture: Gtk.GestureLongPress,
             event_sequence: Gdk.EventSequence) -> None:
         '''
@@ -1645,12 +1656,10 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         :param event_sequence: the event sequence that the event belongs to
         '''
         if _ARGS.debug:
-            LOGGER.debug(
-                'on_flowbox_event_box_long_press_begin() %s %s\n',
-                repr(gesture), repr(event_sequence))
+            LOGGER.debug('%s %s\n', repr(gesture), repr(event_sequence))
 
+    @staticmethod
     def on_flowbox_event_box_long_press_cancel(
-            self,
             gesture: Gtk.GestureLongPress,
             event_sequence: Gdk.EventSequence) -> None:
         '''
@@ -1661,11 +1670,11 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         '''
         if _ARGS.debug:
             LOGGER.debug(
-                'on_flowbox_event_box_long_press_cancel() %s %s\n',
-                repr(gesture), repr(event_sequence))
+                '%s %s\n', repr(gesture), repr(event_sequence))
 
+    @staticmethod
     def on_flowbox_event_box_long_press_cancelled(
-            self, gesture: Gtk.GestureLongPress) -> None:
+            gesture: Gtk.GestureLongPress) -> None:
         '''
         Signal handler called whenever a press moved too far, or was
         released before “pressed” happened.
@@ -1673,9 +1682,7 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         :param gesture: The object which received the signal
         '''
         if _ARGS.debug:
-            LOGGER.debug(
-                'on_flowbox_event_box_long_press_cancelled() %s\n',
-                repr(gesture))
+            LOGGER.debug('%s\n', repr(gesture))
 
     def on_flowbox_event_box_long_press_pressed(
             self,
@@ -1709,10 +1716,10 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         '''
         if _ARGS.debug:
             LOGGER.debug(
-                'on_flowbox_event_box_button_release() '
-                + 'event_button.type=%s ' %event_button.type
-                + 'event_button.window=%s ' %event_button.window
-                + 'event_button.button=%s\n' %event_button.button)
+                'event_button.type=%s '
+                'event_button.window=%s '
+                'event_button.button=%s\n',
+                event_button.type, event_button.window, event_button.button)
         if event_button.button == 1:
             # Call self._emoji_event_box_selected() in the release
             # event because here we know that it has not been a long
@@ -1802,8 +1809,8 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         for skin_tone_variant in skin_tone_variants:
             label = Gtk.Label()
             label.set_text(
-                '<span font="%s %s" fallback="%s">'
-                %(self._font, self._fontsize, str(self._fallback).lower())
+                f'<span font="{self._font} {self._fontsize}" '
+                f'fallback="{str(self._fallback).lower()}">'
                 + html.escape(skin_tone_variant)
                 + '</span>')
             label.set_use_markup(True)
@@ -1884,7 +1891,8 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
             rectangle.width = self._fontsize * 1.5
             rectangle.height = self._fontsize * 1.5
             self._emoji_info_popover.set_pointing_to(rectangle)
-        emoji_info_popover_vbox = Gtk.VBox()
+        emoji_info_popover_vbox = Gtk.Box()
+        emoji_info_popover_vbox.set_orientation(Gtk.Orientation.VERTICAL)
         emoji_info_popover_vbox.set_vexpand(False)
         emoji_info_popover_vbox.set_hexpand(False)
         margin = 0
@@ -1894,12 +1902,11 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         emoji_info_popover_vbox.set_margin_bottom(margin)
         emoji_info_popover_vbox.set_spacing(margin)
         emoji_info_popover_scroll = Gtk.ScrolledWindow()
-        emoji_info_popover_vbox.pack_start(
-            emoji_info_popover_scroll, True, True, 0)
+        emoji_info_popover_vbox.add(emoji_info_popover_scroll)
         emoji_info_popover_listbox = Gtk.ListBox()
         emoji_info_popover_listbox.set_visible(True)
         emoji_info_popover_listbox.set_can_focus(False)
-        emoji_info_popover_listbox.set_vexpand(False)
+        emoji_info_popover_listbox.set_vexpand(True)
         emoji_info_popover_listbox.set_hexpand(False)
         emoji_info_popover_listbox.set_selection_mode(
             Gtk.SelectionMode.NONE)
@@ -1909,9 +1916,10 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         label.set_hexpand(False)
         label.set_vexpand(False)
         label.set_halign(Gtk.Align.START)
+        label.set_valign(Gtk.Align.START)
         label.set_markup(
-            '<span font="%s %s" fallback="%s">'
-            %(self._font, self._fontsize * 3, str(self._fallback).lower())
+            f'<span font="{self._font} {self._fontsize * 3}" '
+            f'fallback="{str(self._fallback).lower()}">'
             + html.escape(emoji)
             + '</span>')
         emoji_info_popover_listbox.insert(label, -1)
@@ -1926,6 +1934,7 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
             label_description.set_hexpand(False)
             label_description.set_vexpand(False)
             label_description.set_halign(Gtk.Align.START)
+            label_description.set_valign(Gtk.Align.START)
             label_description.set_line_wrap(True)
             label_description.set_markup(description)
             emoji_info_popover_listbox.insert(label_description, -1)
@@ -1980,10 +1989,10 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         '''
         if _ARGS.debug:
             LOGGER.debug(
-                'on_flowbox_event_box_button_press() '
-                + 'event_button.type=%s ' %event_button.type
-                + 'event_button.window=%s ' %event_button.window
-                + 'event_button.button=%s\n' %event_button.button)
+                'event_button.type=%s '
+                'event_button.window=%s '
+                'event_button.button=%s\n',
+                event_button.type, event_button.window, event_button.button)
         if event_button.type != Gdk.EventType.BUTTON_PRESS:
             # ignore double and triple clicks i.e. ignore
             # Gdk.EventType.2BUTTON_PRESS and
@@ -2182,7 +2191,8 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         self._font_popover.set_relative_to(self._font_button)
         self._font_popover.set_position(Gtk.PositionType.BOTTOM)
         self._font_popover.set_vexpand(True)
-        font_popover_vbox = Gtk.VBox()
+        font_popover_vbox = Gtk.Box()
+        font_popover_vbox.set_orientation(Gtk.Orientation.VERTICAL)
         margin = 12
         font_popover_vbox.set_margin_start(margin)
         font_popover_vbox.set_margin_end(margin)
@@ -2193,8 +2203,7 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         font_popover_label.set_text(_('Set Font'))
         font_popover_label.set_visible(True)
         font_popover_label.set_halign(Gtk.Align.FILL)
-        font_popover_vbox.pack_start(
-            font_popover_label, False, False, 0)
+        font_popover_vbox.add(font_popover_label)
         font_popover_search_entry = Gtk.SearchEntry()
         font_popover_search_entry.set_can_focus(True)
         font_popover_search_entry.set_visible(True)
@@ -2203,12 +2212,10 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         font_popover_search_entry.set_vexpand(False)
         font_popover_search_entry.connect(
             'search_changed', self.on_font_search_entry_search_changed)
-        font_popover_vbox.pack_start(
-            font_popover_search_entry, False, False, 0)
+        font_popover_vbox.add(font_popover_search_entry)
         self._font_popover_scroll = Gtk.ScrolledWindow()
         self._fill_listbox_font('')
-        font_popover_vbox.pack_start(
-            self._font_popover_scroll, True, True, 0)
+        font_popover_vbox.add(self._font_popover_scroll)
         self._font_popover.add(font_popover_vbox)
         if GTK_VERSION >= (3, 22, 0):
             self._font_popover.popup()
