@@ -322,7 +322,7 @@ class EmojiCandidatesTestCase(unittest.TestCase):
             languages = ['en_US', 'it_IT', 'es_MX', 'es_ES', 'de_DE', 'ja_JP'])
         self.assertEqual(
             mq.candidates('animal')[0][:2],
-            ('🐵', 'cara de mono [animal]'))
+            ('🦍', 'gorilla [animal]'))
         self.assertEqual(
             mq.candidates('dromedary animal')[0][:2],
             ('🐪', 'dromedary camel'))
@@ -430,7 +430,7 @@ class EmojiCandidatesTestCase(unittest.TestCase):
             (' ', 'U+2029 paragraph separator {Paragraph}'))
         self.assertEqual(
             mq.candidates('separator space')[0][:2],
-            (' ', 'U+20 space {Space}'))
+            (' ', 'U+0020 space {Space}'))
 
     def test_candidates_french_text(self) -> None:
         mq = itb_emoji.EmojiMatcher(
